List of functions:

**Notice** Add 'p' infront of any function to make it automaticly print, ex: 'padd(1,2)'


add(x,y)
adds x and y

sub(x,y)
subtracts y from x

mult(x,y)
multiplys x by y

div(x,y)
divides x by y

average(list)
takes the numbers of the list variable and averages them out

exponent(x,y)
x to the power of y

compare(x,y)
compares x to y, 'x < y', 'x > y', 'x = y'

isequal(x,y)
Returns 'Equal' if x and y are equal or 'Not Equal' if x and y are not equal